// author: phga
// backend for the portfolio
// docker-compose up -d
package main

import (
	"html/template"
	"path"

	"log"
	"net/http"
)

func main() {
	// cheap routing
	http.HandleFunc("/", handleIndex)
	http.HandleFunc("/db_user", handleDbUser)

	// provide the inc directory to the useragent
	http.HandleFunc("/static/", handleStatic)
	// listen on port 8080 (I use nginx to proxy this local server)
	log.Fatalln(http.ListenAndServe(":"+config.WebPort, nil))
}

// ---------------------------- HELPER TYPES -----------------------------------

type TmplData struct {
	HeaderData interface{}
	BodyData   interface{}
}

// ------------------------- REQUEST HANDLING ----------------------------------

func handleStatic(w http.ResponseWriter, r *http.Request) {
	http.StripPrefix("/static/", http.FileServer(http.Dir("../../web/static"))).ServeHTTP(w, r)
}

func handleIndex(w http.ResponseWriter, r *http.Request) {
	// Parses all required html files to provide the actual html that is shipped.
	t, _ := getTemplate("layouts/base.html", "main.html", "header.html")
	t.Execute(w, t)
}

func handleDbUser(w http.ResponseWriter, r *http.Request) {
	// Parses all required html files to provide the actual html that is shipped.
	t, _ := getTemplate("layouts/base.html", "db_user.html", "header.html")
	t.Execute(w, t)
}

// ------------------------- TEMPLATE HELPERS ----------------------------------

func getTemplate(files ...string) (*template.Template, error) {
	tmplFolder := "../../web/templates/"
	for i, f := range files {
		files[i] = tmplFolder + f
	}
	// Name has to be the basename of at least one of the template files
	t := template.New(path.Base(files[0]))
	// Add custom helper funcs to template
	t.Funcs(template.FuncMap{
		"UnwrapOID": unwrapObjectID,
	})

	t, err := t.ParseFiles(files...)

	return t, err
}
